@@ -91,9 +91,13 @@ population <- function(name, time, N, parent = NULL, map = FALSE,
   if (!is.logical(map) && !inherits(map, "slendr_map"))
     stop("A simulation landscape must be an object of the class slendr_map", call. = FALSE)
 
-  if (!is.null(parent) && is.logical(map) && map == FALSE)
+  if (!is.null(parent) && is.logical(map) && map == FALSE) {
     map <- attr(parent, "map")
 
+    if (!is.logical(map) && is.null(polygon) && (is.null(center) || is.null(radius)))
+      stop("A descendant of a spatial population cannot be nonspatial", call. = FALSE)
+  }
+
   if (inherits(map, "slendr_map")) {
     check_spatial_pkgs()
 
@@ -458,7 +462,10 @@ set_range <- function(pop, time, center = NULL, radius = NULL,
   if (lock) {
     areas <- slendr::area(result)$area
     area_change <- areas[length(areas)] / areas[length(areas) - 1]
-    prev_N <- utils::tail(sapply(attributes(pop)$history, function(event) event$N), 1)
+    # get all events featuring population size and extract the size of the last one
+    prev_N <- Filter(function(x) "N" %in% colnames(x), attributes(pop)$history) %>%
+      sapply(`[[`, "N") %>%
+      utils::tail(1)
     new_N <- round(area_change * prev_N)
     result <- resize(result, N = new_N, time = time, how = "step")
   }
@@ -784,16 +791,30 @@ world <- function(xrange, yrange, landscape = "naturalearth", crs = NULL,
     map <- sf::st_sf(geometry = sf::st_sfc()) %>%
       set_bbox(xmin = xrange[1], xmax = xrange[2], ymin = yrange[1], ymax = yrange[2])
   } else if (landscape == "naturalearth") {  # Natural Earth data vector landscape
+  scale <- match.arg(scale)
     scale <- match.arg(scale)
-    # the small scale Natural Earth data is bundled with slendr
-    ne_dir <- file.path(tempdir(), "naturalearth")
+
     if (scale == "small") {
-      utils::unzip(system.file("naturalearth/ne_110m_land.zip", package = "slendr"), exdir = ne_dir)
+      map_raw <- sf::read_sf(
+        system.file("naturalearth/ne_110m_land.gpkg", package = "slendr")
+      )
     } else {
-      rnaturalearth::ne_download(scale = scale, type = "land", category = "physical", destdir = ne_dir, load = FALSE)
+      ne_dir <- tempdir()
+      rnaturalearth::ne_download(
+        scale = scale,
+        type = "land",
+        category = "physical",
+        destdir = ne_dir,
+        load = FALSE
+      )
+      map_raw <- rnaturalearth::ne_load(
+        scale = scale,
+        type = "land",
+        category = "physical",
+        destdir = ne_dir
+      )
     }
 
-    map_raw <- rnaturalearth::ne_load(scale = scale, type = "land", category = "physical", destdir = ne_dir)
     sf::st_agr(map_raw) <- "constant"
 
     # define boundary coordinates in the target CRS
@@ -1186,6 +1207,10 @@ area <- function(x) {
 #' points lie within a population spatial boundary at that particular moment of
 #' time.
 #'
+#' Optionally, a name of a single sample from a population can be given, which
+#' will then replace the generic format of \code{"\{population\}_\{number\}"} name.
+#' See example for more detail.
+#'
 #' @param model Object of the class \code{slendr_model}
 #' @param times Integer vector of times (in model time units) at which to
 #'   schedule remembering of individuals in the tree-sequence
@@ -1212,22 +1237,33 @@ area <- function(x) {
 #' path <- system.file("extdata/models/introgression", package = "slendr")
 #' model <- read_model(path)
 #'
-#' # afr and eur objects would normally be created before slendr model compilation,
-#' # but here we take them out of the model object already compiled for this
-#' # example (in a standard slendr simulation pipeline, this wouldn't be necessary)
+#' # afr, eur, and nea objects would normally be created before slendr model
+#' # compilation, but here we take them out of the model object already compiled for
+#' # this example (in a standard slendr simulation pipeline, this wouldn't be necessary)
 #' afr <- model$populations[["AFR"]]
 #' eur <- model$populations[["EUR"]]
+#' nea <- model$populations[["NEA"]]
 #'
 #' # schedule the recording of 10 African and 100 European individuals from a
 #' # given model at 20 ky, 10 ky, 5ky ago and at present-day (time 0)
-#' schedule <- schedule_sampling(
+#' schedule_amh <- schedule_sampling(
 #'   model, times = c(20000, 10000, 5000, 0),
 #'   list(afr, 10), list(eur, 100)
 #' )
+#' # schedule the recording of the Vindija Neanderthal genome
+#' schedule_nea <- schedule_sampling(model, times = 40000, list(nea, 1, "Vindija"))
 #'
 #' # the result of `schedule_sampling` is a simple data frame (note that the locations
 #' # of sampling locations have `NA` values because the model is non-spatial)
+#' schedule <- rbind(schedule_amh, schedule_nea)
 #' schedule
+#'
+#' # simulate a tree sequence
+#' ts <- msprime(model, sequence_length = 1e6, recombination_rate = 1e-8, samples = schedule)
+#'
+#' # inspect the recorded table of samples
+#' ts_samples(ts)
+#'
 #' @export
 schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALSE) {
   if (!inherits(model, "slendr_model"))
@@ -1240,8 +1276,8 @@ schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALS
   sample_counts <- purrr::map(samples, 2)
 
   model_names <- vapply(model$populations, function(pop) pop$pop[1], FUN.VALUE = "character")
-  sample_names <- vapply(sample_pops, function(pop) pop$pop[1], FUN.VALUE = "character")
-  missing_names <- setdiff(sample_names, model_names)
+  pop_names <- vapply(sample_pops, function(pop) pop$pop[1], FUN.VALUE = "character")
+  missing_names <- setdiff(pop_names, model_names)
   if (length(missing_names))
     stop("The following sampled populations are not part of the model: ",
          paste(missing_names, collapse = ", "), call. = FALSE)
@@ -1255,8 +1291,8 @@ schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALS
   if (!all(purrr::map_lgl(sample_pops, ~ inherits(.x, "slendr_pop"))))
     stop("Objects to sample from must be of the class 'slendr_pop'", call. = FALSE)
 
-  if (!all(purrr::map_lgl(sample_counts, ~ .x == round(.x))))
-    stop("Sample counts must be integer numbers", call. = FALSE)
+  if (!all(purrr::map_lgl(sample_counts, ~ .x > 0 &&.x == round(.x))))
+    stop("Sample counts must be non-negative, non-zero integer numbers", call. = FALSE)
 
   # make sure that all sampling times fall in the time window of the simulation itself
   oldest_time <- get_oldest_time(model$populations, model$direction)
@@ -1277,12 +1313,14 @@ schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALS
     lapply(samples, function(s) {
       pop <- s[[1]]
       n <- s[[2]]
+      name <- if (length(s) == 3) s[[3]] else NA
+
       tryCatch(
         {
           check_removal_time(t, pop, direction = model$direction)
           check_present_time(t, pop, direction = model$direction, offset = model$generation_time)
           if (!is.infinite(n)) n <- as.integer(n)
-          dplyr::tibble(time = t, pop = pop$pop[1], n = n)
+          dplyr::tibble(time = t, pop = pop$pop[1], n = n, name = name)
         },
         error = function(cond) {
           if (!strict)
@@ -1325,6 +1363,11 @@ schedule_sampling <- function(model, times, ..., locations = NULL, strict = FALS
     schedule$x <- schedule$y <- schedule$x_orig <- schedule$y_orig <- NA
   }
 
+  named_counts <- table(schedule$name)
+  if (length(named_counts) > 0 && any(named_counts > 1))
+    stop(paste0("Named samples must be unique. The following sample names are duplicated:\n",
+                paste(names(named_counts)[named_counts > 1], sep = " ,")), call. = FALSE)
+
   schedule
 }
 
@@ -1345,9 +1388,7 @@ init_env <- function(quiet = FALSE) {
          "on your system ('", PYTHON_ENV, "').\n\n",
          "To set up a dedicated Python environment you first need to run setup_env().", call. = FALSE)
   else {
-    # reticulate::use_condaenv(PYTHON_ENV, required = TRUE)
-    python_path <- slendr::get_python()
-    reticulate::use_python(python_path, required = TRUE)
+    reticulate::use_condaenv(PYTHON_ENV, required = TRUE)
 
     # this is an awful workaround around the reticulate/Python bug which prevents
     # import_from_path (see zzz.R) from working properly -- I'm getting nonsensical
