@@ -2,10 +2,10 @@
 # functions. This is why it loads simulated outputs via the original ts_read() method (which is still
 # valid, so it actually makes sense to test things this way).
 
-skip_if(!is_slendr_env_present())
+skip_if(!check_dependencies(python = TRUE))
 init_env(quiet = TRUE)
 
-RERUN <- FALSE
+RERUN <- TRUE
 
 # Let's start by defining a couple of parameters for our simulations
 seed <- 42 # random seed
