@@ -1,7 +1,7 @@
 # This unit test script makes sure that a trivially simple slendr model gives exactly the same
 # result (i.e. tree sequence tables) after loading than a pure SLiM script
 
-skip_if(!is_slendr_env_present())
+skip_if(!check_dependencies(python = TRUE))
 init_env(quiet = TRUE)
 
 # total length of the test simulation run
@@ -103,5 +103,7 @@ test_that("simplification on pure SLiM tree sequence retains the correct data",
   # so let's compare the ts_nodes contents by explicitly ordered columns
   cols <- c("pop", "node_id", "time", "time_tskit", "sampled", "remembered",
             "retained", "alive", "pedigree_id", "ind_id", "pop_id")
-  expect_equal(ts_nodes(ts_small)[, cols], ts_nodes(ts_small_loaded)[, cols])
+  abc <- ts_nodes(ts_small)[, cols] %>% dplyr::arrange(pedigree_id)
+  xyz <- ts_nodes(ts_small_loaded)[, cols] %>% dplyr::arrange(pedigree_id)
+  expect_equal(abc, xyz)
 })
